==> blancoReport-0.7.1-src.zip: blancoReport2/blanco/main/blanco/uno/launcher/task/BlancoUnoLauncherStopTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoUnoLauncherStop]̃NX
 */
package blanco.uno.launcher.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.uno.launcher.task.valueobject.BlancoUnoLauncherStopBatchProcessInput;

/**
 * Apache Ant^XN [BlancoUnoLauncherStop]̃NXB
 *
 * OpenOffice.org 2.0.xȍ~̃vZXI܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.uno.launcher.task]BlancoUnoLauncherStopBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancounolauncherstop&quot; classname=&quot;blanco.uno.launcher.task.BlancoUnoLauncherStopTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoUnoLauncherStopTask extends Task {
    /**
     * OpenOffice.org 2.0.xȍ~̃vZXI܂B
     */
    protected BlancoUnoLauncherStopBatchProcessInput fInput = new BlancoUnoLauncherStopBatchProcessInput();

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoUnoLauncherStopTask begin.");

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            if (new BlancoUnoLauncherStopBatchProcess().execute(fInput) != BlancoUnoLauncherStopBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoReport-0.7.3-src.zip: blancoReport2/blanco/main/blanco/uno/launcher/task/BlancoUnoLauncherStopTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoUnoLauncherStop]̃NX
 */
package blanco.uno.launcher.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.uno.launcher.task.valueobject.BlancoUnoLauncherStopProcessInput;

/**
 * Apache Ant^XN [BlancoUnoLauncherStop]̃NXB
 *
 * OpenOffice.org 3 ̃vZXI܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.uno.launcher.task]BlancoUnoLauncherStopBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancounolauncherstop&quot; classname=&quot;blanco.uno.launcher.task.BlancoUnoLauncherStopTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoUnoLauncherStopTask extends Task {
    /**
     * OpenOffice.org 3 ̃vZXI܂B
     */
    protected BlancoUnoLauncherStopProcessInput fInput = new BlancoUnoLauncherStopProcessInput();

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    @Override
    public final void execute() throws BuildException {
        System.out.println("BlancoUnoLauncherStopTask begin.");

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoUnoLauncherStopProcessC^tF[X blanco.uno.launcher.taskpbP[W BlancoUnoLauncherStopProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoUnoLauncherStopProcess proc = new BlancoUnoLauncherStopProcessImpl();
            if (proc.execute(fInput) != BlancoUnoLauncherStopBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
